Django-coop
===============================================
An app to manage a collaborative network of organizations.
The idea is to have something easy to export to RDF, for the moment via D2RQ.
Work in progress, stay tuned...


License
=======
django-coop uses the same license as Django (BSD).
django-coop development was funded by `CREDIS <http://credis.org/>`_, FSE (European Social Fund) and Conseil Regional d'Auvergne.
